@@ -26,6 +26,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
+#include <games-stock.h>
 
 #ifdef HAVE_GNOME
 #include <gnome.h>
@@ -77,6 +78,7 @@ gfloat wager_value = 5.0;
 gfloat balance_value = 0.0;
 gboolean quick_deals = FALSE;
 gboolean show_probabilities = FALSE;
+gboolean never_insurance = FALSE;
 gboolean show_toolbar = TRUE;
 gchar *game_variation = NULL;
 
@@ -87,7 +89,7 @@ bj_make_window_title (gchar *game_name)
 {
         char *title;
 
-        title = g_strdup_printf (_("Blackjack: %s"), game_name);
+        title = g_strdup_printf (_("Blackjack - %s"), game_name);
 
         gtk_window_set_title (GTK_WINDOW (toplevel_window), title); 
 
@@ -210,12 +212,12 @@ static void
 control_menu_set_sensitive (const char *name,
                             gboolean    value)
 {
-        GtkWidget *widget;
+        GtkAction *action;
         char      *path;
 
         path = g_strdup_printf ("/MenuBar/ControlMenu/%s", name);
-        widget = gtk_ui_manager_get_widget (ui, path);
-        gtk_widget_set_sensitive (widget, value);
+        action = gtk_ui_manager_get_action (ui, path);
+        gtk_action_set_sensitive (action, value);
         g_free (path);
 }
 
@@ -251,7 +253,8 @@ create_main_window (void)
         gint          width, height;
         char         *label_string;
         GtkActionGroup *actions;
-        static const char *ui_definition =
+
+        static const char ui_definition[] =
                 "<ui>"
                 "  <menubar name='MenuBar'>"
                 "    <menu name='GameMenu' action='game-menu'>"
@@ -293,22 +296,22 @@ create_main_window (void)
 
         static GtkActionEntry entries [] = {
                 { "game-menu", NULL, N_("_Game") },
-                { "new-game", GTK_STOCK_NEW, N_("_New game"), "<Control>N", N_("Start a new game"), G_CALLBACK (on_game_new_activate) },
-                { "restart-game", GTK_STOCK_REFRESH, N_("_Restart game"), "<Control>R", N_("Restart the current game"), G_CALLBACK (on_game_restart_activate) },
-                { "show-hint", GTK_STOCK_HELP, N_("_Hint"), NULL, N_("Get a hint for the next action"), G_CALLBACK (on_game_hint_activate) },
-                { "quit-game", GTK_STOCK_QUIT, NULL, "<Control>Q", N_("Quit application"), G_CALLBACK (on_game_quit_activate) },
+                { "new-game", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (on_game_new_activate) },
+                { "restart-game", GAMES_STOCK_RESTART_GAME, NULL, NULL, NULL, G_CALLBACK (on_game_restart_activate) },
+                { "show-hint", GAMES_STOCK_HINT, NULL, NULL, NULL, G_CALLBACK (on_game_hint_activate) },
+                { "quit-game", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (on_game_quit_activate) },
                 { "settings-menu", NULL, N_("_Settings") },
-                { "show-preferences", GTK_STOCK_PREFERENCES, NULL, NULL, N_("Show game preferences"), G_CALLBACK (on_preferences_activate) },
+                { "show-preferences", GTK_STOCK_PREFERENCES, NULL, NULL, NULL, G_CALLBACK (on_preferences_activate) },
                 { "control-menu", NULL, N_("_Control") },
-                { "hand-deal", NULL, N_("Deal"), NULL, N_("Deal a new hand"), G_CALLBACK (on_control_deal_activate) },
+                { "hand-deal", NULL, N_("D_eal"), NULL, N_("Deal a new hand"), G_CALLBACK (on_control_deal_activate) },
                 { "hand-hit", NULL, N_("_Hit"), "H", N_("Add a card to the hand"), G_CALLBACK (on_control_hit_activate) },
                 { "hand-stand", NULL, N_("_Stand"), "S", N_("Stop adding cards to the hand"), G_CALLBACK (on_control_stand_activate) },
-                { "hand-surrender", NULL, N_("Surrender"), "R", N_("Surrender the hand"), G_CALLBACK (on_control_surrender_activate) },
-                { "hand-double-down", NULL, N_("_Double down"), "D", N_("Double down"), G_CALLBACK (on_control_double_activate) },
-                { "hand-split", NULL, N_("Split the hand"), "P", N_("Split the hand"), G_CALLBACK (on_control_split_activate) },
+                { "hand-surrender", NULL, N_("S_urrender"), "R", N_("Forfeit this hand for half of your wager"), G_CALLBACK (on_control_surrender_activate) },
+                { "hand-double-down", NULL, N_("_Double down"), "D", N_("Double your wager for a single hit"), G_CALLBACK (on_control_double_activate) },
+                { "hand-split", NULL, N_("S_plit the hand"), "P", N_("Split cards in two new hands"), G_CALLBACK (on_control_split_activate) },
                 { "help-menu", NULL, N_("_Help")},
-                { "show-help-contents", GTK_STOCK_HELP, N_("_Contents"), "F1", N_("Display help for this game"), G_CALLBACK (on_help_contents_activate) },
-                { "show-about", GTK_STOCK_ABOUT, NULL, NULL, N_("About this game"), G_CALLBACK (on_help_about_activate) },
+                { "show-help-contents", GAMES_STOCK_CONTENTS, NULL, NULL, NULL, G_CALLBACK (on_help_contents_activate) },
+                { "show-about", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (on_help_about_activate) },
         };
 
 	static GtkToggleActionEntry toggle_entries [] = {
@@ -317,7 +320,13 @@ create_main_window (void)
 
         toplevel_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
+	games_stock_init();
+	status_bar = gtk_statusbar_new ();
         ui = gtk_ui_manager_new ();
+
+	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (status_bar), FALSE);
+        games_stock_prepare_for_statusbar_tooltips (ui, status_bar);
+
         gtk_ui_manager_add_ui_from_string (ui, ui_definition, -1, &error);
 
         actions = gtk_action_group_new ("Actions");
@@ -371,10 +380,7 @@ create_main_window (void)
         g_free (label_string);
         gtk_box_pack_start (GTK_BOX (group_box), balance_value_label, FALSE, FALSE, 0);
 
-
-        status_bar = gtk_statusbar_new ();
         gtk_box_pack_start (GTK_BOX (hbox), status_bar, TRUE, TRUE, 0);
-
         
         if (!gconf_client)
                 gconf_client = gconf_client_get_default ();
@@ -470,6 +476,14 @@ bj_gconf_quick_deal_cb (GConfClient *client, guint cnxn_id,
         bj_draw_refresh_screen ();
 }
 
+static void
+bj_gconf_never_insurance_cb (GConfClient *client, guint cnxn_id, 
+                             GConfEntry *entry, gpointer user_data)
+{
+        never_insurance = gconf_client_get_bool (client, GCONF_KEY_NEVER_INSURANCE, NULL);
+        bj_draw_refresh_screen ();
+}
+
 static void
 bj_gconf_show_toolbar_cb (GConfClient *client, guint cnxn_id, 
                           GConfEntry *entry, gpointer user_data)
@@ -541,6 +555,19 @@ bj_set_quick_deal (gboolean value)
                                value, NULL);
 }
 
+gboolean
+bj_get_never_insurance ()
+{
+        return never_insurance;
+}
+void
+bj_set_never_insurance (gboolean value)
+{
+        gconf_client_set_bool (bj_gconf_client (), 
+                               GCONF_KEY_NEVER_INSURANCE,
+                               value, NULL);
+}
+
 gchar *
 bj_get_game_variation ()
 {
@@ -611,6 +638,9 @@ bj_gconf_init (GConfClient *client)
         quick_deals = gconf_client_get_bool (client, 
                                              GCONF_KEY_QUICK_DEAL,
                                              NULL);
+        never_insurance = gconf_client_get_bool (client, 
+                                                 GCONF_KEY_NEVER_INSURANCE,
+                                                 NULL);
         show_toolbar = gconf_client_get_bool (client, 
                                               GCONF_KEY_SHOW_TOOLBAR,
                                               NULL);
@@ -631,6 +661,10 @@ bj_gconf_init (GConfClient *client)
                                  GCONF_KEY_QUICK_DEAL,
                                  bj_gconf_quick_deal_cb,
                                  NULL, NULL, NULL);
+        gconf_client_notify_add (client,
+                                 GCONF_KEY_NEVER_INSURANCE,
+                                 bj_gconf_never_insurance_cb,
+                                 NULL, NULL, NULL);
         gconf_client_notify_add (client,
                                  GCONF_KEY_SHOW_TOOLBAR,
                                  bj_gconf_show_toolbar_cb,
@@ -668,7 +702,7 @@ main (int argc, char *argv [])
                               GCONF_CLIENT_PRELOAD_NONE, NULL);
 
 #ifdef HAVE_GNOME
-        gnome_program_init ("blackjack", VERSION,
+        gnome_program_init ("Blackjack", VERSION,
                             LIBGNOMEUI_MODULE,
                             argc, argv,
                             GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
