@@ -33,36 +33,10 @@ extern int COLUMNS;
 
 extern int BLOCK_SIZE;
 
-enum SlotType 
-{
-	EMPTY, 
-	FALLING, 
-	LAYING
-};
-
-struct Block
-{
-	SlotType what;
-	int color;
-	GnomeCanvasItem* item;
-};
-
-extern GdkPixmap *pix;
-extern GdkPixbuf **pic;
-
 extern int color_next;
 extern int blocknr_next;
 extern int rot_next;
 
-extern int blocknr;
-extern int rot;
-extern int color;
-
-extern int posx;
-extern int posy;
-
-extern int nr_of_colors;
-
 extern bool random_block_colors;
 
 class Field;
@@ -88,8 +62,8 @@ private:
 
         GList * themeList;
         
-	char *blockPixmap;
 	char *bgPixmap;
+	gint themeno;
 	
 	Field *field;
 	Preview *preview;
@@ -116,6 +90,7 @@ private:
 	static void dragDrop(GtkWidget *widget, GdkDragContext *context,
 			     gint x, gint y, GtkSelectionData *data, 
 			     guint info, guint time, Tetris *t);
+	static gboolean configure (GtkWidget *widget, GdkEventConfigure *event, Tetris *t);
 	static int timeoutHandler(void *d);
 	static int gameQuit(GtkAction *action, void *d);
 	static int gameNew(GtkAction *action, void *d);
@@ -147,8 +122,8 @@ private:
 	void setOptions ();
 	void writeOptions ();
         void setupScoreState ();
+	void manageFallen();
 	
-	GdkPixbuf *image;
 	GdkPixbuf *bgimage;
 	gboolean usebg;
 
@@ -187,8 +162,6 @@ private:
 	GtkAction *end_game_action;
 	GtkAction *preferences_action;
 
-	void manageFallen();
-
 	bool fastFall;
 	int fastFallPoints;
         bool dropBlock;
